.markItUp * {
    margin: 0;
    padding:0;
    outline:none;
}

.markItUp a:link,
.markItUp a:visited {
    color:#000;
    text-decoration:none;
}

.markItUp  {
    margin:5px 0 5px 0;
}

.markItUpContainer  {
    margin: 20px 0;
    font:11px Verdana, Arial, Helvetica, sans-serif;
}

.markItUpEditor {
    font: 14px 'Courier New', Courier, monospace;
    padding:5px;
    height: 320px;
    clear:both;
    line-height:18px;
    overflow:auto;
}

.markItUpEditor,
.markItUpPreviewFrame {
    width: 70% !important;
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
}

.markItUpPreviewFrame {
    overflow: auto;
    height: 350px;
    margin: 15px 0 5px 0;
    border: 2px solid #aaa;
}

.markItUpFooter {
    width:100%;
}

.markItUpResizeHandle {
    overflow:hidden;
    width:22px; height:5px;
    margin-left:auto;
    margin-right:auto;
    cursor:n-resize;
}

.markItUpHeader ul li {
    list-style:none;
    float:left;
    position:relative;
}

.markItUpHeader ul li:hover > ul{
    display:block;
}

.markItUpHeader ul .markItUpDropMenu {
    margin-right:5px;
}

.markItUpHeader ul .markItUpDropMenu li {
    margin-right:0px;
}

.markItUpHeader {
    height: 25px;
}

.markItUpHeader ul ul {
    display:none;
    position:absolute;
    top:18px; left:0px;
    background:#FFF;
    border:1px solid #000;
}

.markItUpHeader ul ul li {
    float:none;
    border-bottom:1px solid #000;
}

.markItUpHeader ul .markItUpSeparator {
    margin:0 10px;
    width:1px;
    height:16px;
    overflow:hidden;
    background-color:#CCC;
}

.markItUpHeader ul ul .markItUpSeparator {
    width:auto; height:1px;
    margin:0px;
}

.markItUpHeader ul ul ul {
    position:absolute;
    top:-1px; left:150px;
}

.markItUpHeader ul ul ul li {
    float:none;
}

.markItUpHeader ul a {
    margin-right: 10px;
    padding: 0;
    display: block;
    width: 16px;
    height:16px;
    text-indent:-10000px;
    background: url('../img/editor.png') top left no-repeat;
}

.markItUpHeader ul ul a {
    display:block;
    text-indent:0;
    width:120px;
    padding:5px 5px 5px 25px;
    background-position:2px 50%;
}

.markItUpHeader ul ul a:hover  {
    color:#FFF;
    background-color:#000;
}

/* Restructuredtext Buttons */
.markItUp .markItUpButton1 a {
    background-position: -32px 0;
}

.markItUp .markItUpButton2 a {
    background-position: -48px 0;
}
.markItUp .markItUpButton3 a {
    background-position: -64px 0;
}
.markItUp .markItUpButton4 a {
    background-position: -80px 0;
}
.markItUp .markItUpButton5 a {
    background-position: -96px 0;
}

.markItUp .markItUpButton6 a {
    /* bold. default position. */
}
.markItUp .markItUpButton7 a {
    background-position: -112px 0;
}

.markItUp .markItUpButton8 a {
    background-position: -144px 0;
}
.markItUp .markItUpButton9 a {
    background-position: -160px 0;
}

.markItUp .markItUpButton10 a {
    background-position: -176px 0;
}
.markItUp .markItUpButton11 a {
    background-position: -128px 0;
}

.markItUp .markItUpButton12 a {
    background-position: -208px 0;
}
.markItUp .markItUpButton13 a {
    background-position: -16px 0;
}

.markItUp .preview a {
    background-position: -192px 0;
}
