{% load trans from i18n %}
{% load url from future %}

<ul>
  {% for object in object_list %}
    <li class="row-fluid">
      <div class="span2">
        <time data-datetime="{{ object.updated_at }}">
          {{ object.updated_at|date:"b d, Y"|upper }}
        </time>
      </div>
      <div class="span10">
        <h2 class="article-title">
          <a href="{% url 'radpress-detail' object.slug %}">
            {{ object.title }}
          </a>
        </h2>
      </div>
    </li>
  {% empty %}
    <li>{% trans "There's no blog entry." %}</li>
  {% endfor %}
</ul>
