{% load trans from i18n %}
{% load url from future %}

<form action="{% url 'radpress-search' %}" method="GET" class="form-inline search-form">
  <div class="input-append">
    <input type="text" name="q" class="span2" placeholder="{% trans "Search..." %}"
      /><button class="btn"><i class="icon-search"></i></button>
  </div>
</form>
