body {
    padding: 0 0 40px 0;
    background: #232323;
}
header {
  background-color: #333;
  padding: 50px 50px 30px 50px;
  color: #eee;
}
.article,
.set-content-margin,
footer {
  padding: 0 40px;
}
.article img.cover {
    margin-top: 20px;
}
nav {
    padding: 0 30px;
}
#wrapper {
  background: #EDEFF4;
}
.article,
.set-content-margin,
#sidebar {
  padding-top: 40px;
  padding-bottom: 40px;
  padding-right: 30px;
}
#sidebar ul li {
    margin-bottom: 10px;
}
#sidebar ul li a {
    text-decoration: none;
}
#sidebar h2 {
    margin-bottom: 20px;
}
.sidebar-box {
    margin-bottom: 50px;
}
footer {
  border-top: 1px solid #bbb;
  background: #ccc;
  -webkit-border-bottom-right-radius: 5px;
  -webkit-border-bottom-left-radius: 5px;
  -moz-border-radius-bottomright: 5px;
  -moz-border-radius-bottomleft: 5px;
  border-bottom-right-radius: 5px;
  border-bottom-left-radius: 5px;
}
footer p,
footer a {
  margin: 0;
  font-size: 14px;
  line-height: 50px;
  text-shadow: #fff 1px 1px 2px;
}
footer a.menu {
  padding-left: 10px;
  font-size: 11px;
}
.article {
  padding-bottom: 10px;
}

.article time {
    margin-bottom: 10px;
    display: block;
    font-size: 16px;
    color: #999;
    text-shadow: #fff 1px 1px 0;
}

.article h1.entry-title {
  font-size: 2em;
  line-height: 1em;
}
.article p,
.article li {
    font-size: 1.1em;
    line-height: 1.4em;
}
.article p {
  margin: 25px 0;
}
#content {
    background: #eee;
    border-right: 1px solid #ddd;
    min-height: 350px;
}

#articles .article {
    padding-bottom: 0;
    border-bottom: 1px solid #ddd;
}

.article-footer {
    margin-top: 20px;
    padding: 5px 10px;
    background-color: #ddd;
}

.article-footer .row-fluid,
.article-footer .span6 {
    min-height: 0 !important;
}

#articles .article a.more {
    font-size: 12px;
    color: #005580;
    text-decoration: none;
}

#articles .article a.more:hover {
    color: #08C;
}

#blog-form h1.page-title {
    margin-bottom: 20px;
}
#blog-form #id_title {
    height: 40px;
    width: 100%;
    font-size: 20px;
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
}
#blog-form textarea {
  width: 100%;
  resize: vertical;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
}
#blog-form #slug {
  font-size: 11px;
}
#blog-form #slug span {
    vertical-align: middle;
    display: inline-block;
}
#blog-form #slug input {
  margin: 0;
  padding: 0;
  font-size: 11px;
  background: transparent;
  border: none;
  box-shadow: none;
  -moz-box-shadow: none;
}
#blog-form #slug input:hover,
#blog-form #slug input:focus {
  background: #fdf6e3;
}
#blog-form input#id_title {
  margin-bottom: 0;
}
h3.blog-archives {
  text-align: center;
  line-height: 80px;
}
h3.blog-archives a {
  color: #bbb;
  text-shadow: #fff 1px 1px 0;
  text-decoration: none;
}
h3.blog-archives a:hover {
  color: #268bd2;
}
#message .alert {
    margin-bottom: 0;
}
#blog-archive h1 {
    padding-bottom: 20px;
    font-size: 42px;
    border-bottom: 1px dotted #bbb;
}
#blog-archive h2.article-title {
    vertical-align: middle;
    line-height: 50px;
    font-weight: normal;
}
#blog-archive ul {
    margin: 0;
    padding: 0;
    list-style-type: none;
}
#blog-archive li {
    margin-top: 20px;
}
#blog-archive span,
#blog-archive time {
    display: block;
    vertical-align: middle;
    line-height: 50px;
    text-align: center;
    color: #aaa;
}
#blog-archive time {
    font-size: 14px;
}
#archive-tags a.remove-tag {
    margin: -25px 0 7px 0;
    display: block;
}
.pager {
    margin: 0;
    padding: 20px;
}

.tags a {
    margin: 0 10px 10px 0;
    padding: 3px 5px;
    display: inline-block;
}

pre {
    padding: 10px 20px;
    margin-bottom: 30px;
    background-color: #002B36;
    color: #93A1A1;
    font-family: 'Bitstream Vera Sans Mono', 'Courier', monospace;
    font-size: 1em;
    display: block;
    border-radius: 0;
    white-space: pre;
    word-wrap: normal;
    overflow: auto;
    border: none;
}

table {
    box-sizing: border-box;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
}

table td.code {
    width: 100%;
}

table td.linenos {
    vertical-align: top;
}

table td.linenos pre {
    padding-right: 7px;
    width: 20px;
    text-align: right;
    background-color: #073642;
}

table.highlighttable td {
    padding: 0;
}

@media (max-width: 767px) {
    .sidebar-span {
        border-top: 1px solid #ddd;
    }

    #sidebar {
        padding: 10px !important;
        margin: 10px;
    }
}

/* Disqus Settings */
#disqus_thread {
    margin-top: 50px;
}

/* Default Pygmentize Output */
.hll { background-color: #ffffcc }
.c { color: #586E75 } /* Comment */
.err { color: #93A1A1 } /* Error */
.g { color: #93A1A1 } /* Generic */
.k { color: #859900 } /* Keyword */
.l { color: #93A1A1 } /* Literal */
.n { color: #93A1A1 } /* Name */
.o { color: #859900 } /* Operator */
.x { color: #CB4B16 } /* Other */
.p { color: #93A1A1 } /* Punctuation */
.cm { color: #586E75 } /* Comment.Multiline */
.cp { color: #859900 } /* Comment.Preproc */
.c1 { color: #586E75 } /* Comment.Single */
.cs { color: #859900 } /* Comment.Special */
.gd { color: #2AA198 } /* Generic.Deleted */
.ge { color: #93A1A1; font-style: italic } /* Generic.Emph */
.gr { color: #DC322F } /* Generic.Error */
.gh { color: #CB4B16 } /* Generic.Heading */
.gi { color: #859900 } /* Generic.Inserted */
.go { color: #93A1A1 } /* Generic.Output */
.gp { color: #93A1A1 } /* Generic.Prompt */
.gs { color: #93A1A1; font-weight: bold } /* Generic.Strong */
.gu { color: #CB4B16 } /* Generic.Subheading */
.gt { color: #93A1A1 } /* Generic.Traceback */
.kc { color: #CB4B16 } /* Keyword.Constant */
.kd { color: #268BD2 } /* Keyword.Declaration */
.kn { color: #859900 } /* Keyword.Namespace */
.kp { color: #859900 } /* Keyword.Pseudo */
.kr { color: #268BD2 } /* Keyword.Reserved */
.kt { color: #DC322F } /* Keyword.Type */
.ld { color: #93A1A1 } /* Literal.Date */
.m { color: #2AA198 } /* Literal.Number */
.s { color: #2AA198 } /* Literal.String */
.na { color: #93A1A1 } /* Name.Attribute */
.nb { color: #B58900 } /* Name.Builtin */
.nc { color: #268BD2 } /* Name.Class */
.no { color: #CB4B16 } /* Name.Constant */
.nd { color: #268BD2 } /* Name.Decorator */
.ni { color: #CB4B16 } /* Name.Entity */
.ne { color: #CB4B16 } /* Name.Exception */
.nf { color: #268BD2 } /* Name.Function */
.nl { color: #93A1A1 } /* Name.Label */
.nn { color: #93A1A1 } /* Name.Namespace */
.nx { color: #93A1A1 } /* Name.Other */
.py { color: #93A1A1 } /* Name.Property */
.nt { color: #268BD2 } /* Name.Tag */
.nv { color: #268BD2 } /* Name.Variable */
.ow { color: #859900 } /* Operator.Word */
.w { color: #93A1A1 } /* Text.Whitespace */
.mf { color: #2AA198 } /* Literal.Number.Float */
.mh { color: #2AA198 } /* Literal.Number.Hex */
.mi { color: #2AA198 } /* Literal.Number.Integer */
.mo { color: #2AA198 } /* Literal.Number.Oct */
.sb { color: #586E75 } /* Literal.String.Backtick */
.sc { color: #2AA198 } /* Literal.String.Char */
.sd { color: #93A1A1 } /* Literal.String.Doc */
.s2 { color: #2AA198 } /* Literal.String.Double */
.se { color: #CB4B16 } /* Literal.String.Escape */
.sh { color: #93A1A1 } /* Literal.String.Heredoc */
.si { color: #2AA198 } /* Literal.String.Interpol */
.sx { color: #2AA198 } /* Literal.String.Other */
.sr { color: #DC322F } /* Literal.String.Regex */
.s1 { color: #2AA198 } /* Literal.String.Single */
.ss { color: #2AA198 } /* Literal.String.Symbol */
.bp { color: #268BD2 } /* Name.Builtin.Pseudo */
.vc { color: #268BD2 } /* Name.Variable.Class */
.vg { color: #268BD2 } /* Name.Variable.Global */
.vi { color: #268BD2 } /* Name.Variable.Instance */
.il { color: #2AA198 } /* Literal.Number.Integer.Long */
