{% load trans from i18n %}
{% load url from future %}

<h2>{% trans "Latest Posts" %}</h2>

<ul>
  {% for object in object_list %}
    <li>
      <a href="{% url 'radpress-detail' object.slug %}">
        <h4>{{ object.title }}</h4>
      </a>
    </li>
  {% endfor %}
</ul>
