{% extends "radpress/base.html" %}

{% load trans from i18n %}

{% block content %}
  <div id="blog-archive" class="set-content-margin">
    <h1>{% trans "Search Results" %}</h1>

    {% include "radpress/_archive_list.html" %}
  </div>
{% endblock %}

{% block sidebar %}
  <div class="sidebar-box">
    {% include "radpress/_search_form.html" %}
  </div>
{% endblock %}
